#!/usr/bin/env lua
--[[
A simple HTTP server

If a request is not a HEAD method, then reply with "Hello world!"

Usage: lua examples/server_hello.lua [<port>]
]]
require'game_srv'
require'resource/strings'

local port = 5001

local http_server = require "http.server"
local http_headers = require "http.headers"

local function reply(myserver, stream) -- luacheck: ignore 212
	-- Read in headers
	local req_headers = assert(stream:get_headers())
	local req_method = req_headers:get ":method"

	-- Log request to stdout
	assert(io.stdout:write(string.format('[%s] "%s %s HTTP/%g"  "%s" "%s"\n',
		os.date("%d/%b/%Y:%H:%M:%S %z"),
		req_method or "",
		req_headers:get(":path") or "",
		stream.connection.version,
		req_headers:get("referer") or "-",
		req_headers:get("user-agent") or "-"
	)))
    local path = req_headers:get(":path")
    local params = ''
    local x = string.find(path,"?")
    if x~=nil then
        params = string.sub(path,x+1,string.len(path))
        path = string.sub(path,0,x-1)
    end

    -- print(path..'....'..params)
    local t = string.split(params, "&") or {params}
    local p = {}
    -- print(params)
    -- print(t)
    if params~='' then
        for idx,s in ipairs(t) do
            local kv = string.split(s,"=")
            p[kv[1]] = kv[2]
            -- print(kv[1]..'...'..kv[2])
        end
    end

    local res = 'Not found route!'
    if path=='/login' then res = login(p) end
    if path=='/order' then res = order(p) end
    if path=='/game_prop' then res = game_prop(p) end
    if path=='/payC' then res = payC(p) end
    if path=='/game_user' then res = game_user(p) end
    if path=='/game_user_free' then res = game_user_free(p) end


	-- Build response headers
	local res_headers = http_headers.new()
	res_headers:append(":status", "200")
	res_headers:append("content-type", "text/plain")
	-- Send headers to client; end the stream immediately if this was a HEAD request
	assert(stream:write_headers(res_headers, req_method == "HEAD"))
	if req_method ~= "HEAD" then
		-- Send body, ending the stream
		assert(stream:write_chunk(res, true))
	end
end

local myserver = assert(http_server.listen {
	host = "localhost";
	port = port;
	onstream = reply;
	onerror = function(myserver, context, op, err, errno) -- luacheck: ignore 212
		local msg = op .. " on " .. tostring(context) .. " failed"
		if err then
			msg = msg .. ": " .. tostring(err)
		end
		assert(io.stderr:write(msg, "\n"))
	end;
})

-- Manually call :listen() so that we are bound before calling :localname()
assert(myserver:listen())
do
	local bound_port = select(3, myserver:localname())
	assert(io.stderr:write(string.format("Now listening on port %d\n", bound_port)))
end
-- Start the main server loop
assert(myserver:loop())